/*
** Copyright (C) 10 Feb 1999 Jonas Munsin <jmunsin@iki.fi>
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
** 
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
** 
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software 
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#define SIZE_BUF_SIZE 9

enum { MAX_ROWS=1000 };

extern long int totalsize, sectorsize;
extern GList *exclude_pattern_list;
extern int selected_files[MAX_ROWS];

extern GtkWidget *total_size, *exclude_pattern_combo, *clist, *exclude_dir;
extern GtkWidget *mkisofs_follow_symlinks, *mkisofs_include_all, *mkisofs_include_dirname;

void mark_size_inaccurate(void);
gint resize_clist_col_ratio(GtkWidget *, GdkEvent *, gpointer);
void create_filepicker(GtkWidget *, config_cdr_data *);

